@@ -177,10 +177,11 @@ def init():
     player1 = Player()
     global location1
     location1 = Location()
-    if not os.path.isfile("data/src/main/resources/plugin.yml"):
-        os.makedirs("data/src/main/resources")
-    if not os.path.isfile("data/src/main/java/Main/Main.java"):
-        os.makedirs("data/src/main/java/Main")
+    if os.path.isdir("data/src/main/resources"):
+        import shutil
+        shutil.rmtree("data/src/main")
+    os.makedirs("data/src/main/resources")
+    os.makedirs("data/src/main/java/Main")
     file = open("data/src/main/resources/plugin.yml","w")
     file.write("name: minepy\nmain: Main.Main\nversion: 1.0\napi-version: 1.16\n")
     file.close()
@@ -806,6 +807,7 @@ def make(server,**setting):
                 if not var_list.__contains__(var_name):
                     data = code.split("=")[1]
                     if data.__contains__('"'):
+                        javacode = space.getspace(javacode)
                         javacode += 'String '+var_name+";\n"
                     else:
                         javacode = space.getspace(javacode)
